@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.5   2015/11/11
+ * Version: 1.8.6   2019/08/20
  */
 
 #ifndef _SECURITY_CCSECURITY_INTERNAL_H
@@ -195,6 +195,10 @@ struct path {
 #define f_vfsmnt f_path.mnt
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 16, 0)
+#define d_inode(dentry) (dentry)->d_inode
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 14)
 
 /**
